package com.dragon.fuck.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.dragon.fuck.domain.EmsUser;
import com.dragon.fuck.exception.ServiceException;
import com.dragon.fuck.mapper.EmsUserMapper;
import com.dragon.fuck.service.EmsUserService;
import lombok.extern.log4j.Log4j2;
import org.springframework.security.crypto.bcrypt.BCryptPasswordEncoder;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 用户表(EmsUser)表服务实现类
 *
 * @author fengkai
 * @since 2024-01-02 20:32:30
 */
@Service("emsUserService")
@Log4j2
public class EmsUserServiceImpl extends ServiceImpl<EmsUserMapper, EmsUser> implements EmsUserService {

    @Override
    public boolean insert(EmsUser emsUser) {
        LambdaQueryWrapper<EmsUser> wrapper = new LambdaQueryWrapper<>();
        wrapper.eq(EmsUser::getUserName, emsUser.getUserName()).or()
                .eq(EmsUser::getCount, emsUser.getCount()).or()
                .eq(EmsUser::getUserCode, emsUser.getUserCode());
        if (baseMapper.selectCount(wrapper) > 0) {
            throw new ServiceException("用户名、账户或用户编码已存在");
        }
        BCryptPasswordEncoder bCryptPasswordEncoder = new BCryptPasswordEncoder();
        String encode = bCryptPasswordEncoder.encode(emsUser.getPassword());
        emsUser.setPassword(encode);
        log.info("加密后的密码是:{}", encode);
        // 使用insertIfNotExists方法简化插入逻辑

        return baseMapper.insert(emsUser) > 0;
    }

    @Override
    public List<EmsUser> selectByName(String userName) {
        LambdaQueryWrapper<EmsUser> wrapper = new LambdaQueryWrapper<>();
        wrapper.like(EmsUser::getUserName, userName);
        return baseMapper.selectList(wrapper);
    }



    public static void main(String[] args) {
        BCryptPasswordEncoder bCryptPasswordEncoder = new BCryptPasswordEncoder();
        String encode = bCryptPasswordEncoder.encode("123456");
        String encode1 = bCryptPasswordEncoder.encode("123456");
        System.out.println(encode);
        System.out.println(encode1);
        boolean matches = bCryptPasswordEncoder.matches("123456", encode1);
        System.out.println(encode.equals(encode1));
    }
}

